
# Slot: batch_size


Number of nodes to include in a single batch.

URI: [https://w3id.org/neat/nodeEmbeddingsParams__batch_size](https://w3id.org/neat/nodeEmbeddingsParams__batch_size)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
